@@ -423,11 +423,11 @@ theme_par <- function(base_size = par()$ps, base_family = par()$family) {
         axis.ticks = element_line(colour = par()$fg),
         legend.title = element_text(colour = par()$fg),
         legend.text = element_text(colour = par()$fg),
-        legend.margin = unit(0.2, "cm"),
+        legend.spacing = unit(0.2, "cm"),
         legend.key = element_rect(colour = NA),
-        panel.margin = unit(half_line, "pt"),
-        panel.margin.x = NULL,
-        panel.margin.y = NULL,
+        panel.spacing = unit(half_line, "pt"),
+        panel.spacing.x = NULL,
+        panel.spacing.y = NULL,
         panel.background = element_rect(fill = NA, colour = par()$col),
         panel.grid = element_blank(),
         plot.background = element_rect(colour = NA),
